config

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 24, 2016 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type File

type File struct {
	Target    string
	SourceDir string
	Logger    logger
}

File represents a config file to be built from a list of sources

func NewFile

func NewFile(target, sourceDir string) *File

NewFile creates a File from target and sourceDir

func (*File) Rebuild

func (f *File) Rebuild() error

Rebuild validate sources and target and overwrite the target with the content of the sources appended.

func (*File) Validate

func (f *File) Validate() error

Validate makes sure source folder exists and that the target file can be created

Jump to