package
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Nov 24, 2016
License: Apache-2.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type File struct {
Target string
SourceDir string
Logger logger
}
File represents a config file to be built from a list of sources
NewFile creates a File from target and sourceDir
Rebuild validate sources and target and overwrite the target with the content
of the sources appended.
Validate makes sure source folder exists and that the target file can be
created
Source Files
¶
Click to show internal directories.
Click to hide internal directories.